# Yks

### An experiment on Python project setup.

[![Build Status](https://travis-ci.com/tonikarppi/yks.svg?branch=master)](https://travis-ci.com/tonikarppi/yks)

This project does not really do anything practical. It's a test for properly configuring a modern Python project with testing and Continuos Integration.

## Installation
This project is available in the testing pypi 